@@ -15,6 +15,8 @@ has 'password';
 has 'proxy';
 has 'ua' => sub { Mojo::UserAgent->new; };
 
+our $VERSION = '1.2.12.1';
+
 
 sub _execute {
     my $c    = shift;
@@ -32,7 +34,9 @@ sub _execute {
     my $url = Mojo::URL->new($c->url);
     $url->userinfo($c->user.':'.$c->password) if defined $c->user && defined $c->password;
 
-    $url->path($url->path.'/api/'.$args->{api}.'/'.$args->{method});
+    my $path = $url->path;
+    $path =~ s#/$##;
+    $url->path($path.'/api/'.$args->{api}.'/'.$args->{method});
 
     $args->{args}->{apikey} = $c->apikey;
 
@@ -1470,7 +1474,7 @@ Etherpad - interact with Etherpad API
 
 =head1 VERSION
 
-version 1.2.12.0
+version 1.2.12.1
 
 =head1 SYNOPSIS
 
@@ -1983,6 +1987,17 @@ See L<http://etherpad.org/doc/v1.5.6/#index_pads>
  Returns   : An array or an array reference depending on the context, containing the pads names
  See       : http://etherpad.org/doc/v1.5.6/#index_listallpads
 
+=head1 INSTALL
+
+After getting the tarball on https://metacpan.org/release/Etherpad, untar it, go to the directory and:
+
+    perl Makefile.PL
+    make
+    make test
+    make install
+
+If you are on a windows box you should use 'nmake' rather than 'make'.
+
 =head1 BUGS and SUPPORT
 
 You can find documentation for this module with the perldoc command.
